@@ -300,9 +300,15 @@ private:
     PatchReviewPlugin *m_plugin;
 };
 
-PatchReviewPlugin::~PatchReviewPlugin() {
+PatchReviewPlugin::~PatchReviewPlugin()
+{
     removeHighlighting();
-    delete m_patch;
+
+    // Tweak to work around a crash on OS X; see https://bugs.kde.org/show_bug.cgi?id=338829
+    // and http://qt-project.org/forums/viewthread/38406/#162801
+    if (m_patch) {
+        m_patch->deleteLater();
+    }
 }
 
 void PatchReviewPlugin::clearPatch( QObject* _patch ) {
@@ -550,6 +556,7 @@ void PatchReviewPlugin::exporterSelected( QAction* action ) {
 
     if( exporter ) {
         qDebug() << "exporting patch" << exporter << action->text();
+        // for git projects, m_patch will be a VCSDiffPatchSource instance
         exporter->extension<IPatchExporter>()->exportPatch( patch() );
     }
 }
