@@ -81,7 +81,7 @@ ProjectTreeView::ProjectTreeView( QWidget *parent )
     setItemDelegate(new ProjectModelItemDelegate(this));
 
     connect( this, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(popupContextMenu(QPoint)) );
-    connect( this, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(slotActivated(QModelIndex)) );
+    connect( this, SIGNAL(activated(QModelIndex)), this, SLOT(slotActivated(QModelIndex)) );
 
     connect( ICore::self(), SIGNAL(aboutToShutdown()),
              this, SLOT(aboutToShutdown()));
@@ -112,14 +112,14 @@ QList<ProjectFileItem*> fileItemsWithin(const QList<ProjectBaseItem*> items)
 
 QList<ProjectBaseItem*> topLevelItemsWithin(QList<ProjectBaseItem*> items)
 {
-    qSort(items.begin(), items.end(), ProjectBaseItem::urlLessThan);
-    KUrl lastFolder;
+    qSort(items.begin(), items.end(), ProjectBaseItem::pathLessThan);
+    Path lastFolder;
     for (int i = items.size() - 1; i >= 0; --i)
     {
-        if (lastFolder.isParentOf(items[i]->url()))
+        if (lastFolder.isParentOf(items[i]->path()))
             items.removeAt(i);
         else if (items[i]->folder())
-            lastFolder = items[i]->url();
+            lastFolder = items[i]->path();
     }
     return items;
 }
@@ -187,13 +187,13 @@ void ProjectTreeView::dropEvent(QDropEvent* event)
 
             QList<ProjectBaseItem*> usefulItems = topLevelItemsWithin(selectionCtxt->items());
             filterDroppedItems(usefulItems, destItem);
-            QList<KUrl> urls;
+            Path::List paths;
             foreach (ProjectBaseItem* i, usefulItems) {
-                urls << i->url();
+                paths << i->path();
             }
             bool success = false;
             if (executedAction == copy) {
-                success =~ destItem->project()->projectFileManager()->copyFilesAndFolders(urls, folder);
+                success =~ destItem->project()->projectFileManager()->copyFilesAndFolders(paths, folder);
             } else if (executedAction == move) {
                 success =~ destItem->project()->projectFileManager()->moveFilesAndFolders(usefulItems, folder);
             }
@@ -204,11 +204,10 @@ void ProjectTreeView::dropEvent(QDropEvent* event)
 
                 //and select new items
                 QItemSelection selection;
-                foreach (const KUrl &url, urls) {
-                    KUrl targetUrl = folder->url();
-                    targetUrl.addPath(url.fileName());
+                foreach (const Path &path, paths) {
+                    const Path targetPath(folder->path(), path.lastPathSegment());
                     foreach (ProjectBaseItem *item, folder->children()) {
-                        if (item->url().equals(targetUrl, KUrl::CompareWithoutTrailingSlash)) {
+                        if (item->path() == targetPath) {
                             QModelIndex indx = mapFromItem( item );
                             selection.append(QItemSelectionRange(indx, indx));
                             setCurrentIndex(indx);
@@ -275,10 +274,14 @@ QModelIndex ProjectTreeView::mapFromItem(const ProjectBaseItem* item)
 
 void ProjectTreeView::slotActivated( const QModelIndex &index )
 {
+    if ( QApplication::keyboardModifiers() & Qt::CTRL || QApplication::keyboardModifiers() & Qt::SHIFT ) {
+        // Do not open file when Ctrl or Shift is pressed; that's for selection
+        return;
+    }
     KDevelop::ProjectBaseItem *item = index.data(ProjectModel::ProjectItemRole).value<ProjectBaseItem*>();
     if ( item && item->file() )
     {
-        emit activateUrl( item->file()->url() );
+        emit activate( item->file()->path() );
     }
 }
 //TODO test whether this could be replaced by projectbuildsetwidget.cpp::showContextMenu_appendActions
@@ -408,7 +411,7 @@ bool ProjectTreeView::event(QEvent* event)
             m_idx=idx;
             ProjectFileItem* file=it->file();
             KDevelop::DUChainReadLocker lock(KDevelop::DUChain::lock());
-            TopDUContext* top= DUChainUtils::standardContextForUrl(file->url());
+            TopDUContext* top= DUChainUtils::standardContextForUrl(file->path().toUrl());
             
             if(m_tooltip)
                 m_tooltip->close();
